# emoji-data

[![CircleCI](https://circleci.com/gh/tanbro/emoji-data.svg?style=svg)](https://circleci.com/gh/tanbro/emoji-data)

A small library, it does:

- Load `Emoji` data from the data file defined in [Unicode® Emoji](https://unicode.org/emoji/charts/index.html).
- Provide a class holding the data, and representing `Emoji` characters.
- Regular Express for `Emoji` characters
